@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2018 ECMWF.
+ * Copyright 2005-2019 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -38,7 +38,7 @@ int main(int argc,char* argv[])
     const char* infile = "../../data/bufr/asca_139.bufr";
     char key_name[128];
 
-    in=fopen(infile,"r");
+    in=fopen(infile,"rb");
     if (!in) {
         printf("ERROR: unable to open file %s\n", infile);
         return 1;
@@ -71,12 +71,6 @@ int main(int argc,char* argv[])
 
         printf("Number of values: %ld\n",numObs);
 
-        /* Allocate memory for the values to be read. Each
-         * parameter must have the same number of values. */
-        lat = (double*)malloc(numObs*sizeof(double));
-        lon = (double*)malloc(numObs*sizeof(double));
-        bscatter = (double*)malloc(numObs*sizeof(double));
-
         /* Get latitude */
         sprintf(key_name,"latitude");
 
@@ -87,6 +81,10 @@ int main(int argc,char* argv[])
             return 1;
         }
 
+        /* Allocate memory for the values to be read. Each
+         * parameter must have the same number of values. */
+        lat = (double*)malloc(numObs*sizeof(double));
+
         /* Get the values (from all the subsets) */
         CODES_CHECK(codes_get_double_array(h,key_name,lat,&len),0);
 
@@ -101,6 +99,7 @@ int main(int argc,char* argv[])
         }
 
         /* Get the values (from all the subsets) */
+        lon = (double*)malloc(numObs*sizeof(double));
         CODES_CHECK(codes_get_double_array(h,key_name,lon,&len),0);
 
         /* Get backScatter for beam two. We use an access by condition for this key. */
@@ -114,15 +113,14 @@ int main(int argc,char* argv[])
         }
 
         /* Get the values (from all the subsets) */
+        bscatter = (double*)malloc(numObs*sizeof(double));
         CODES_CHECK(codes_get_double_array(h,key_name,bscatter,&len),0);
 
         /* Print the values */
         printf("pixel   lat    lon     backscatter    \n");
         printf("-------------------------------\n");
-
         for(i=0; i < numObs; i++) {
-            printf("%4d %.3f %.3f %.3f \n",
-                    i+1,lat[i],lon[i],bscatter[i]);
+            printf("%4d %.3f %.3f %.3f \n", i+1,lat[i],lon[i],bscatter[i]);
         }
 
         /* Delete handle */
