@@ -79,7 +79,7 @@ int main(int argc, char **argv)
     }
 
     {
-        pthread_t workers[NUM_THREADS];
+        pthread_t* workers = malloc(NUM_THREADS * sizeof(pthread_t));
         for (i = 0; i < NUM_THREADS; i++) {
             struct v *data = (struct v *) malloc(sizeof(struct v));
             data->number = i;
@@ -99,6 +99,7 @@ int main(int argc, char **argv)
                 pthread_join(workers[i], NULL);
             }
         }
+        free (workers);
     }
 
     return 0;
